@@ -168,8 +168,6 @@ class FilterMultiplexer(EventObserver):
 #
 class ParseContext(OutputStream, EventDispatcher):
 
-    __c1 = 0
-
     def __init__(self,
                  output,
                  termenc='UTF-8',
@@ -179,6 +177,8 @@ class ParseContext(OutputStream, EventDispatcher):
         self.__termenc = termenc
         self.__scanner = scanner
         self.__handler = handler
+        self._c1 = 0
+
         if buffering:
             try:
                 from cStringIO import StringIO
@@ -218,9 +218,9 @@ class ParseContext(OutputStream, EventDispatcher):
         elif c < 0xd800:
             self._output.write(unichr(c))
         elif c < 0xdc00:
-            self.__c1 = c
+            self._c1 = c
         elif c < 0xe000:
-            self._output.write(unichr(self.__c1) + unichr(c))
+            self._output.write(unichr(self._c1) + unichr(c))
         elif c < 0x10000:
             self._output.write(unichr(c))
         else:  # c > 0x10000
@@ -233,7 +233,7 @@ class ParseContext(OutputStream, EventDispatcher):
     def writestring(self, data):
         try:
             self._target_output.write(data)
-        except:
+        except Exception:
             self._output.write(data)
 
 # OutputStream
@@ -423,6 +423,13 @@ class DefaultPTY(PTY):
         #fcntl.ioctl(self._master, termios.TIOCSTART, 0)
         termios.tcflow(self._master, termios.TCOON)
 
+class MockParseContext(ParseContext):
+
+    def __init__(self):
+        from StringIO import StringIO
+        output = StringIO()
+        ParseContext.__init__(self, output)
+
 ###############################################################################
 #
 # Terminal
@@ -441,7 +448,7 @@ class Terminal:
                                     scanner=DefaultScanner(),
                                     handler=inputhandler,
                                     buffering=False)
-        outputcontext = ParseContext(output=sys.stdout,
+        outputcontext = ParseContext(output=self.tty,
                                      termenc=termenc,
                                      scanner=DefaultScanner(),
                                      handler=outputhandler,
@@ -493,7 +500,8 @@ class Session:
         self._ttymap = {}
 
     def add_subtty(self, term, lang, command, row, col,
-                   termenc, inputhandler, outputhandler, listener):
+                   termenc, inputhandler,
+                   outputhandler, listener):
 
         tty = DefaultPTY(term, lang, command, sys.stdin)
         tty.resize(row, col)
@@ -529,8 +537,8 @@ class Session:
             self._outputcontext.flush()
         else:
             def dispatch_esc():
+                self._inputparser.flush()
                 self._inputparser.reset()
-                self._inputcontext.dispatch_char(0x1b)
                 self._inputhandler.handle_draw(self._outputcontext)
                 self._outputhandler.handle_draw(self._outputcontext)
                 #self._inputcontext.flush()
